/*--------------------------------*-C-*---------------------------------*
 * File:
 *	fft.h
 *
 * ---------------------------------------------------------------------*
 * Re[]:	real value array
 * Im[]:	imaginary value array
 * nTotal:	total number of complex values
 * nPass:	number of elements involved in this pass of transform
 * nSpan:	nspan/nPass = number of bytes to increment pointer
 *		in Re[] and Im[]
 * isign:	exponent: +1= fwd transform  -1= rev transform
 * max_factors:	maximum value of any prime factor
 *    max_perm:	maximum number of prime factors
 * ----------------------------------------------------------------------
 * See the comments in the code for correct usage!
 */

#ifndef _FFT_H
#define _FFT_H

extern void fft_free (void);

/* double precision routine */
extern int fftn (int ndim, const int dims[], double Re[], double Im[],
		 int isign, double scaling);

/* float precision routine */
extern int fftnf (int ndim, const int dims[], float Re[], float Im[],
		  int isign, double scaling);

/* double precision routine */
extern int fftradix (double *Re, double *Im,
		     size_t nTotal, size_t nPass, size_t nSpan, int isign,
		     int max_factors, int max_perm);

/* float precision routine */
extern int fftradixf (float *Re, float *Im,
		      size_t nTotal, size_t nPass, size_t nSpan, int isign,
		      int max_factors, int max_perm);
#endif	/* _FFT_H */
